---
name: ""
description: ""
---

Agent: if you are seeing this,
the user has not yet filled out this information.

Please alert the user to this fact.
Tell them "the role definition for <your role> is not filled out."
If you don't have a role defined, use "default role".
